# Changelog

## 0.1.0-alpha.2 (2025-05-15)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/octogen-systems/octogen-py-api/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** update via SDK Studio ([79894f7](https://github.com/octogen-systems/octogen-py-api/commit/79894f7c8cae4266867ad4b493d789668a48179c))


### Chores

* **ci:** upload sdks to package manager ([bf6eac2](https://github.com/octogen-systems/octogen-py-api/commit/bf6eac2ce4240871573b7cdeee91a1203d9e5ca7))

## 0.1.0-alpha.1 (2025-05-14)

Full Changelog: [v0.0.1-alpha.1...v0.1.0-alpha.1](https://github.com/octogen-systems/octogen-py-api/compare/v0.0.1-alpha.1...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([313e76d](https://github.com/octogen-systems/octogen-py-api/commit/313e76d7dd31553efac2264b2ffbc1a8ec2383f1))

## 0.0.1-alpha.1 (2025-05-14)

Full Changelog: [v0.0.1-alpha.0...v0.0.1-alpha.1](https://github.com/octogen-systems/octogen-py-api/compare/v0.0.1-alpha.0...v0.0.1-alpha.1)

### Chores

* update SDK settings ([b062541](https://github.com/octogen-systems/octogen-py-api/commit/b062541cd48785c811d7917c785f8ecdff069fa9))
* update SDK settings ([5220f36](https://github.com/octogen-systems/octogen-py-api/commit/5220f3690b3054ac5a3bf8343e8f3f8797c89437))
